<?php
// $Id: flir.admin.inc,v 1.1.2.3 2010/04/15 17:53:08 hadsie Exp $

/**
 * @file
 * Contains the admin settings form.
 */

/**
 * FAPI implementation for the admin settings form.
 */
function flir_admin_settings() {
  $form = array();

  // Reset the flir cache
  $fonts = flir_fonts(TRUE);
  $default_path = libraries_get_path('facelift') . '/fonts';

  // Get a list of all themes
  $themes = array();
  foreach (list_themes() as $key => $theme) {
    $themes[$key] = $theme->name;
  }
  $themes = array('all' => 'all') + $themes;

  $form['flir_font_path'] = array(
    '#type' => 'textfield',
    '#title' => t('Font path'),
    '#description' => t('The custom path to your fonts. This should be the relative path from the drupal root.'),
    '#default_value' => variable_get('flir_font_path', $default_path),
  );

  $form['flir_cache_path'] = array(
    '#type' => 'textfield',
    '#title' => t('Font cache path'),
    '#description' => t('The path to the font cache directory. Relative to your sites files directory.'),
    '#default_value' => variable_get('flir_cache_path', 'flir_cache'),
  );

  $flir_replacements = variable_get('flir_replacements', array());
  $form['flir_replacements'] = array(
    '#type' => 'fieldset',
    '#title' => t('Flir replacements'),
    '#tree' => TRUE,
  );

  $count = count($flir_replacements) + 2;
  for ($i = 0; $i < $count; $i++) {
    $replacement = $flir_replacements[$i];

    $form['flir_replacements'][$i] = array(
      '#type' => 'fieldset',
      '#title' => t('Flir replacement ' . ($i + 1)),
      '#collapsible' => FALSE,
    );

    $form['flir_replacements'][$i]['selector'] = array(
      '#type' => 'textfield',
      '#title' => t('Items to replace with Flir generated text'),
      '#default_value' => $replacement['selector'],
      '#description' => t("The CSS selector to replace with a FLIR image."),
    );

    $form['flir_replacements'][$i]['font'] = array(
      '#type' => 'select',
      '#title' => t('Font to use'),
      '#options' => $fonts,
      '#default_value' => !empty($replacement['font']) ? $replacement['font'] : 'default',
      '#description' => t("The font to use for this FLIR replacement."),
    );

    $form['flir_replacements'][$i]['theme'] = array(
      '#type' => 'select',
      '#title' => t('Theme to apply this replacement on'),
      '#description' => t('Select a theme if you wish to apply this replacement to a particular theme'),
      '#options' => $themes,
      '#default_value' => !empty($replacement['theme']) ? $replacement['theme'] : 'all',
    );
  }

  // List out the fonts that currently exist in the system and show a demo
  // of what the rendered version will look like.
  $form['flir_fonts'] = array(
    '#type' => 'fieldset',
    '#title' => t('Font samples'),
    '#collapsible' => TRUE,
    '#collapsed' => FALSE,
  );

  foreach ($fonts as $family => $filename) {
    if ($family == 'default') continue;

    $form['flir_fonts'][$family] = array(
      '#type' => 'fieldset',
      '#title' => $filename,
      '#collapsible' => FALSE,
    );

    $class = preg_replace('/[^A-Za-z\-]/', '', $family);
    $form['flir_fonts'][$family]['example'] = array(
      '#value' => $family,
      '#prefix' => '<div style="font-size: 36px !important;" class="' . $class . '">',
      '#suffix' => '</div>',
    );

    flir_replace(".$class", $family);
  }

  $form['submit'] = array(
    '#type' => 'submit',
    '#value' => t('Save'),
  );

  return $form;
}

/**
 * FAPI submit callback for the admin settings form.
 */
function flir_admin_settings_submit($form, &$form_state) {
  $replacements = array();
  foreach ($form_state['values']['flir_replacements'] as $replacement) {
    // Filter out the empty values
    if (!empty($replacement['selector'])) {
      $replacements[] = $replacement;
    }
  }
  variable_set('flir_replacements', $replacements);

  variable_set('flir_font_path', $form_state['values']['flir_font_path']);
  variable_set('flir_cache_path', $form_state['values']['flir_cache_path']);
}
